@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -247,7 +247,7 @@ _OptionalStartSnapshotRequestRequestTypeDef = TypedDict(
     "_OptionalStartSnapshotRequestRequestTypeDef",
     {
         "ParentSnapshotId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "Description": str,
         "ClientToken": str,
         "Encrypted": bool,
